check: Check if user annotations are correct or not

Description Usage Arguments Examples

View source: R/training_check.R

Description

Check if user annotations are correct or not

Usage

1
check(img_number)

Arguments

img_number

Integer to indicate which image to check as per the order the user annotated the images in

Examples

1
2
3
check(1)
check(2)
check(3)

ACEMS/r2vr documentation built on Dec. 17, 2021, 6:40 a.m.